package com.cooleshow.teacher.ui.income;

import android.os.Bundle;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.View;

import androidx.annotation.Nullable;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.alibaba.android.arouter.launcher.ARouter;
import com.cooleshow.base.router.RouterPath;
import com.cooleshow.base.ui.activity.BaseMVPActivity;
import com.cooleshow.base.utils.ToastUtils;
import com.cooleshow.teacher.R;
import com.cooleshow.teacher.bean.WithdrawalInfoBean;
import com.cooleshow.teacher.contract.WithdrawalContract;
import com.cooleshow.teacher.databinding.ActivityWithdrawalBinding;
import com.cooleshow.teacher.presenter.income.WithdrawalPresenter;

import java.text.DecimalFormat;

import io.rong.imkit.utils.StatusBarUtil;

/**
 * 创建日期：2022/5/23 17:29
 *
 * @author Ryan
 * 类说明：
 */
@Route(path = RouterPath.IncomeCenter.TEACHER_MINE_WITHDRAWAL)
public class WithdrawalActivity extends BaseMVPActivity<ActivityWithdrawalBinding, WithdrawalPresenter> implements WithdrawalContract.WithdrawalView, View.OnClickListener {
    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.tv_right_text:
                ARouter.getInstance().build(RouterPath.IncomeCenter.TEACHER_MINE_WITHDRAWAL_RECORD)
                        .navigation();
                break;
            case R.id.tv_withdrawal_all:
                viewBinding.etPrice.setText(mWithdrawalInfo.amountWithdrawal + "");
                break;
            case R.id.tv_confirm_withdrawal:
                String amountWithdrawal = viewBinding.etPrice.getText().toString().trim();
                if (Double.parseDouble(amountWithdrawal) <= mWithdrawalInfo.withdrawalServiceFee) {
                    ToastUtils.showShort("结算金额需要大于手续费");
                    break;
                }
                if (null == mWithdrawalInfo.userBankCard) {
                    ToastUtils.showShort("请先绑定银行卡");
                    ARouter.getInstance().build(RouterPath.MineCenter.MINE_MY_BANKCARD)
                            .navigation();
                    break;
                }


                presenter.userAccountPage(amountWithdrawal, mWithdrawalInfo.userBankCard.id + "");
                break;
        }
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        StatusBarUtil.setStatusBarDarkTheme(this, true);
    }

    @Override
    protected void initView() {
        initMidTitleToolBar(viewBinding.toolbarInclude.toolbar, "结算");
        viewBinding.toolbarInclude.tvRightText.setTextColor(getResources().getColor(com.cooleshow.base.R.color.common_black));
        viewBinding.toolbarInclude.tvRightText.setVisibility(View.VISIBLE);
        viewBinding.toolbarInclude.tvRightText.setText("结算记录");
        viewBinding.toolbarInclude.tvRightText.setOnClickListener(this);
        viewBinding.tvWithdrawalAll.setOnClickListener(this);
        viewBinding.tvConfirmWithdrawal.setOnClickListener(this);

        viewBinding.etPrice.addTextChangedListener(new TextWatcher() {
            @Override
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {

            }

            @Override
            public void onTextChanged(CharSequence s, int start, int before, int count) {

            }

            @Override
            public void afterTextChanged(Editable s) {
                String price = viewBinding.etPrice.getText().toString();
                if (TextUtils.isEmpty(price)) {
                    viewBinding.etPrice.setTextSize(20);
                } else {
                    viewBinding.etPrice.setTextSize(32);
                }

            }
        });
    }

    @Override
    protected ActivityWithdrawalBinding getLayoutView() {
        return ActivityWithdrawalBinding.inflate(getLayoutInflater());
    }

    @Override
    protected WithdrawalPresenter createPresenter() {
        return new WithdrawalPresenter();
    }


    @Override
    public void initData() {
        super.initData();
        presenter.getWithdrawalInfo();
    }

    private WithdrawalInfoBean mWithdrawalInfo;

    @Override
    public void getWithdrawalInfoSuccess(WithdrawalInfoBean data) {
        mWithdrawalInfo = data;
        viewBinding.tvAvailablePrice.setText("可结算余额 " + getTwoDecimal(data.amountWithdrawal));
        viewBinding.tvServiceFee.setText("单次收入结算时，平台将收取" + getTwoDecimal(data.withdrawalServiceFee) + "元手续费");
        if (null != data.userBankCard) {
            viewBinding.tvBankName.setText(data.userBankCard.bankName);
        }
    }

    private String getTwoDecimal(double num) {
        DecimalFormat df = new DecimalFormat("#,##0.00");
        String str = df.format(num);
        return str;

    }

    @Override
    public void doWithdrawalSuccess(Object o) {
        ARouter.getInstance().build(RouterPath.IncomeCenter.TEACHER_MINE_WITHDRAWAL_SUCCESS)
                .navigation();
        finish();
    }
}
