package com.cooleshow.teacher.ui.score;

import android.content.res.Configuration;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.viewpager.widget.ViewPager;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.cooleshow.base.router.RouterPath;
import com.cooleshow.base.ui.activity.BaseMVPActivity;
import com.cooleshow.base.utils.ToastUtils;
import com.cooleshow.teacher.R;
import com.cooleshow.teacher.adapter.MineLiveCoursePagerAdapter;
import com.cooleshow.teacher.bean.MusicSheetShareBean;
import com.cooleshow.teacher.contract.MineScoreActContract;
import com.cooleshow.teacher.databinding.ActivityMineScoreBinding;
import com.cooleshow.teacher.presenter.score.MineScoreActPresenter;
import com.cooleshow.teacher.ui.web.HtmlActivity;
import com.cooleshow.teacher.widgets.DialogUtils;
import com.cooleshow.teacher.widgets.FileUtils;
import com.google.android.material.tabs.TabLayout;
import com.umeng.socialize.ShareAction;
import com.umeng.socialize.UMShareAPI;
import com.umeng.socialize.UMShareListener;
import com.umeng.socialize.bean.SHARE_MEDIA;
import com.umeng.socialize.media.UMImage;
import com.umeng.socialize.shareboard.SnsPlatform;
import com.umeng.socialize.utils.ShareBoardlistener;

import org.jetbrains.annotations.NotNull;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import io.rong.imkit.utils.StatusBarUtil;

/**
 * 创建日期：2022/5/20 16:34
 *
 * @author Ryan
 * 类说明：
 */
@Route(path = RouterPath.ScoreCenter.TEACHER_MINE_SCORE)
public class MineScoreActivity extends BaseMVPActivity<ActivityMineScoreBinding, MineScoreActPresenter> implements MineScoreActContract.MineScoreActView, View.OnClickListener {
    @Override
    public void onClick(View view) {
        switch (view.getId()) {
            case R.id.tv_right:
                presenter.musicSheetShare();
                break;
        }

    }
    private TabLayout tabLayout;
    private ViewPager viewPager;

    @Override
    protected void initView() {
        initMidTitleToolBar(viewBinding.toolbarInclude.toolbar, "我的曲谱");
        viewBinding.toolbarInclude.tvRight.setBackgroundResource(R.drawable.icon_toolbar_share);
        viewBinding.toolbarInclude.tvRight.setVisibility(View.VISIBLE);
        viewBinding.toolbarInclude.tvRight.setOnClickListener(this);
        tabLayout = viewBinding.tablayout;
        viewPager = viewBinding.viewpager;
        viewPager.setCurrentItem(0);
        mShareListener = new CustomShareListener(this);
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        StatusBarUtil.setStatusBarDarkTheme(this, true);
    }
    private String musicianAuthStatus;
    @Override
    public void initData() {
        super.initData();
        musicianAuthStatus= getIntent().getStringExtra("musicianAuthStatus");
        initTabLayoutAndViewPager();
    }

    @Override
    protected ActivityMineScoreBinding getLayoutView() {
        return ActivityMineScoreBinding.inflate(getLayoutInflater());
    }

    @Override
    protected MineScoreActPresenter createPresenter() {
        return new MineScoreActPresenter();
    }

    private List<String> titles = new ArrayList<String>(Arrays.asList("已上架", "审核中", "审核失败"));
    private List<String> auditStatusList = new ArrayList<String>(Arrays.asList("PASS", "DOING", "UNPASS"));
    private List<Fragment> fragments = new ArrayList<>();

    private void initTabLayoutAndViewPager() {
        tabLayout.removeAllTabs();
        fragments.clear();
        for (int i = 0; i < titles.size(); i++) {
            tabLayout.addTab(tabLayout.newTab().setText(titles.get(i)));
            Fragment adFragment = MineScoreFragment.newInstance(auditStatusList.get(i),musicianAuthStatus);
            fragments.add(adFragment);
        }
        viewPager.setAdapter(new MineLiveCoursePagerAdapter(getSupportFragmentManager(), fragments, titles));
        tabLayout.setupWithViewPager(viewPager);
    }

    @Override
    public void musicSheetShareSuccess(MusicSheetShareBean data) {
        showScoreShareDialog(data);
    }

    private void showScoreShareDialog(MusicSheetShareBean data) {
        DialogUtils.showScoreShare(this,data, new DialogUtils.ActionShareCallback() {

            @Override
            public void onShareClick(Bitmap bitmap) {
                share(bitmap);
            }
        });
    }
    private ShareAction mShareAction;
    private UMShareListener mShareListener;
    private void share(Bitmap bitmap){
        mShareAction = new ShareAction(MineScoreActivity.this).setDisplayList(
                        SHARE_MEDIA.WEIXIN, SHARE_MEDIA.WEIXIN_CIRCLE, SHARE_MEDIA.QQ, SHARE_MEDIA.QZONE, SHARE_MEDIA.SINA)
                .setShareboardclickCallback(new ShareBoardlistener() {
                    @Override
                    public void onclick(SnsPlatform snsPlatform, SHARE_MEDIA share_media) {
                        UMImage image = new UMImage(MineScoreActivity.this, bitmap);
                        new ShareAction(MineScoreActivity.this).withMedia(image)
                                .setPlatform(share_media)
                                .setCallback(mShareListener)
                                .share();

                    }
                });
        mShareAction.open();
    }
    private static class CustomShareListener implements UMShareListener {

        private WeakReference<MineScoreActivity> mActivity;

        private CustomShareListener(MineScoreActivity activity) {
            mActivity = new WeakReference(activity);
        }

        @Override
        public void onStart(SHARE_MEDIA platform) {

        }

        @Override
        public void onResult(SHARE_MEDIA platform) {

            if (platform.name().equals("WEIXIN_FAVORITE")) {
                ToastUtils.showShort("收藏成功啦");
            } else {
                if (platform != SHARE_MEDIA.MORE && platform != SHARE_MEDIA.SMS
                        && platform != SHARE_MEDIA.EMAIL
                        && platform != SHARE_MEDIA.FLICKR
                        && platform != SHARE_MEDIA.FOURSQUARE
                        && platform != SHARE_MEDIA.TUMBLR
                        && platform != SHARE_MEDIA.POCKET
                        && platform != SHARE_MEDIA.PINTEREST

                        && platform != SHARE_MEDIA.INSTAGRAM
                        && platform != SHARE_MEDIA.GOOGLEPLUS
                        && platform != SHARE_MEDIA.YNOTE
                        && platform != SHARE_MEDIA.EVERNOTE) {
                    ToastUtils.showShort("分享成功啦");
                }

            }
        }

        @Override
        public void onError(SHARE_MEDIA platform, Throwable t) {
            if (platform != SHARE_MEDIA.MORE && platform != SHARE_MEDIA.SMS
                    && platform != SHARE_MEDIA.EMAIL
                    && platform != SHARE_MEDIA.FLICKR
                    && platform != SHARE_MEDIA.FOURSQUARE
                    && platform != SHARE_MEDIA.TUMBLR
                    && platform != SHARE_MEDIA.POCKET
                    && platform != SHARE_MEDIA.PINTEREST

                    && platform != SHARE_MEDIA.INSTAGRAM
                    && platform != SHARE_MEDIA.GOOGLEPLUS
                    && platform != SHARE_MEDIA.YNOTE
                    && platform != SHARE_MEDIA.EVERNOTE) {
                ToastUtils.showShort("分享失败啦");

            }

        }

        @Override
        public void onCancel(SHARE_MEDIA platform) {
            ToastUtils.showShort("分享取消了");
        }
    }

    @Override
    public void onConfigurationChanged(@NonNull @NotNull Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (mShareAction != null) {
            mShareAction.close();
        }
    }
    @Override
    public void onDestroy() {
        super.onDestroy();
        UMShareAPI.get(MineScoreActivity.this).release();
    }
}
